@@ -22,8 +22,8 @@
  * 02110-1301 USA
 */
 /*******************************************************************************/
-#ifndef _weather_common_h
-#define _weather_common_h 1
+#ifndef _livewp_common_h
+#define _livewp_common_h 1
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -37,6 +37,10 @@
 #define GETTEXT_PACKAGE "livewp"
 #include <glib/gi18n-lib.h>
 
+/* Position of plugin on desktop */
+#define Xstartposition 700 
+#define Ystartposition 448 
+
 #define THEME_PATH "/usr/share/livewp/theme"
 #define SHORT_TIMER 75 /* 100 milisecond */
 //#define LONG_TIMER 5*60*1000 /* 10 minutes */
@@ -47,11 +51,24 @@ enum { SHORT_TIMER_TYPE, LONG_TIMER_TYPE };
 #define TOWN_LEVEL 0 
 #define TRAM_LEVEL 20 
 
+typedef struct _Scene Scene;
+struct _Scene 
+{
+    GSList * actors;
+    gint daytime;
+    gint timer_type;
+    gint wind_orientation; // +/- 1
+    double wind_angle; // [-1 .. 1]
+    guint seed; /* init value for random  */
+    guint notification;
+};
 
 typedef struct _AWallpaperPlugin AWallpaperPlugin;
 typedef struct _AWallpaperPluginClass AWallpaperPluginClass;
 typedef struct _Animation_WallpaperPrivate Animation_WallpaperPrivate;
 
+
+
 struct _Animation_WallpaperPrivate
 {
     gint long_timer;
@@ -65,6 +82,10 @@ struct _Animation_WallpaperPrivate
     DBusConnection      *dbus_conn;
     DBusConnection      *dbus_conn_session;
     osso_context_t      *osso;
+    gint xapplet;
+    gint yapplet;
+    Scene *scene;
+    GHashTable * hash_scene_func;
 };
 
 struct _AWallpaperPlugin
@@ -75,33 +96,21 @@ struct _AWallpaperPlugin
 
 struct _AWallpaperPluginClass
 {
-    HDHomePluginItemClass parent_class;
-
+  HDHomePluginItemClass parent_class;
 };
 
-typedef struct {
-    GtkWidget * widget;
-    gchar  *name;
-    gchar *filename;
-    gint x;
-    gint y;
-    gint z;
-    gint width;
-    gint height;
-    gint scale;
-    gint opacity; 
-    gboolean visible;
-    void (*func_change)(gpointer, gpointer);
-    time_t time_start_animation;
-    gint duration_animation;
-    void (*func_probability)(gpointer);
-    GPtrArray *child;
 
-} Actor;
 #define LIVEWP_SIGNAL_INTERFACE "org.maemo.livewp"
 #define LIVEWP_SIGNAL_PATH "/org/maemo/livewp"
 #define LIVEWP_SIGNAL_RELOAD_CONFIG_INTERFACE "org.maemo.livewp.reload_config"
 #define LIVEWP_SIGNAL_RELOAD_CONFIG_PATH "/org/maemo/livewp/reload_config"
 #define LIVEWP_RELOAD_CONFIG "reload_config"
 #define LIVEWP_RELOAD_PLUGIN "reload_plugin"
+
+/* For DBUS notification */
+#define NOTIFY_SIGNAL_INTERFACE "org.freedesktop.Notifications"
+#define NOTIFY_SIGNAL_PATH "/org/freedesktop/Notifications"
+#define NOTIFY_MEMBER "Notify"
+#define CLOSENOTIFY_MEMBER "NotificationClosed"
+
 #endif
