@@ -445,7 +445,7 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
     g_hash_table_insert(priv->hash_scene_func, g_strdup("Modern"), (gpointer)&init_scene_Modern);
     g_hash_table_insert(priv->hash_scene_func, g_strdup("Matrix"), (gpointer)&init_scene_Matrix);
 //#endif
-    priv->theme = g_strdup("Modern");
+    //priv->theme = g_strdup("Modern");
     desktop_plugin->priv->main_widget = gtk_fixed_new();
 
     gtk_widget_set_size_request(desktop_plugin->priv->main_widget, 100, 32);
@@ -481,7 +481,7 @@ animation_wallpaper_plugin_init (AWallpaperPlugin *desktop_plugin)
 
     
     //fprintf(stderr, "!!!theme = %s\n", priv->theme);
-    snprintf(str, sizeof(str) - 1, "%s", "init_scene2");
+    //snprintf(str, sizeof(str) - 1, "%s", "init_scene2");
     //fprintf(stderr, " str = %s\n", str);
     priv->scene = NULL;
 #if 0
