@@ -23,9 +23,15 @@
 */
 /*******************************************************************************/
 #include "livewp-common.h"
+#include <unistd.h>
 void lw_settings(Animation_WallpaperPrivate *priv, gpointer data);
 void save_config(Animation_WallpaperPrivate *priv);
+gboolean check_applet_state(void);
 void reload_scene(AWallpaperPlugin *desktop_plugin);
 GtkWidget* create_settings(void);
 void show_settings(GtkWidget *widget, Animation_WallpaperPrivate *priv);
+void start_applet(void);
+void stop_applet(void);
+void send_dbus_signal (Animation_WallpaperPrivate *priv, const gchar *interface,
+                  const gchar *path, const gchar *member);
 
